PROGRAM_NAME='MainProgram'
(***********************************************************)
(***********************************************************)
(*  FILE_LAST_MODIFIED_ON: 04/05/2006  AT: 09:00:25        *)
(***********************************************************)
(* System Type : NetLinx                                   *)
(***********************************************************)
(* REV HISTORY:                                            *)
(***********************************************************)
(*
    $History: $
*)


(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

dvTP = 10001:1:0

vdvGUILanguageManager = 33001:1:0


(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

//////////////////////////////////////////////////
//////////     BUTTONS DEFINITIONS      //////////
//////////////////////////////////////////////////

integer BUTTON_SETTINGS_POPUP_SHOW 	= 361
integer BUTTON_SETTINGS_POPUP_CLOSE 	= 527
integer BUTTON_SETTINGS_LANGUAGE_SHOW 	= 534
integer BUTTON_SETTINGS_LANGUAGE_CLOSE	= 637

integer BUTTON_LANGUAGE_SELECT_LANG1 	= 641
integer BUTTON_LANGUAGE_SELECT_LANG2 	= 642

integer BUTTON_MODULE_ACTIVATED 	= 401


char GUI_TEXT_FILE_PATH_LIST[][50] = {'data/gui/gui_en.txt', 
				      'data/gui/gui_ar.txt'}


(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

integer currentLanguageIndex = 1

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE


(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)

define_function showSettingsBarPopupPage(dev targetTP)
{
    char popupName[50]

    popupName = '[Settings]Settings'
    
    send_command dvTP, "'@PPN-', popupName"
}

define_function hideSettingsBarPopupPage(dev targetTP)
{
    char popupName[50]

    popupName = '[Settings]Settings'
    
    send_command dvTP, "'@PPF-', popupName"

}

define_function showLanguageSelectPopupPage(dev targetTP)
{
    char popupName[50]

    popupName = '[settings]Language'
    
    send_command dvTP, "'@PPN-', popupName"
}

define_function hideLanguageSelectPopupPage(dev targetTP)
{
    char popupName[50]
    
    popupName = '[settings]Language'
    
    send_command dvTP, "'@PPF-', popupName"
}


(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

define_module 'GUILanguageManager_V1_0_0' mod1(vdvGUILanguageManager)


(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
DEFINE_EVENT



//////////////////////////////////
// Touch Panel Data Event 	// 
//////////////////////////////////

data_event[dvTP]
{
    online:
    {
	// Updating the GUI on the touch panel when it comes online 
	pulse[vdvGUILanguageManager, currentLanguageIndex]
	
	// Updating the module activation status feedback on the touch panel 
	[dvTP, BUTTON_MODULE_ACTIVATED] = [vdvGUILanguageManager, 201]

	// Updating the selected language feedback on the touch panel
	[dvTP, BUTTON_LANGUAGE_SELECT_LANG1] = (currentLanguageIndex == 1)
	[dvTP, BUTTON_LANGUAGE_SELECT_LANG2] = (currentLanguageIndex == 2)
    }
}

//////////////////////////////////
// Touch Panel Buttons Events 	// 
//////////////////////////////////

button_event[dvTP, BUTTON_SETTINGS_POPUP_SHOW]
{
    push:
    {
	showSettingsBarPopupPage(button.input.device)
    }
}

button_event[dvTP, BUTTON_SETTINGS_POPUP_CLOSE]
{
    push:
    {
	hideSettingsBarPopupPage(button.input.device)
    }
}

button_event[dvTP, BUTTON_SETTINGS_LANGUAGE_SHOW]
{
    push:
    {
	showLanguageSelectPopupPage(button.input.device)
    }
}

button_event[dvTP, BUTTON_SETTINGS_LANGUAGE_CLOSE]
{
    push:
    {
	hideLanguageSelectPopupPage(button.input.device)
    }
}

button_event[dvTP, BUTTON_LANGUAGE_SELECT_LANG1]
button_event[dvTP, BUTTON_LANGUAGE_SELECT_LANG2]
{
    push:
    {
	integer languageIndex
	
	languageIndex = button.input.channel - BUTTON_LANGUAGE_SELECT_LANG1 + 1
	
	pulse[vdvGUILanguageManager, languageIndex]

	hideSettingsBarPopupPage(button.input.device)
	hideLanguageSelectPopupPage(button.input.device)
    }
}


//////////////////////////////////
// Module Data Event 		// 
//////////////////////////////////

data_event[vdvGUILanguageManager]
{
    online:
    {
	send_string 0, "'Module is Online'"
	
	// Setting touch panel device number to be used by the module 
	send_command vdvGUILanguageManager, "'TPDev-', itoa(dvTP.NUMBER),',', itoa(dvTP.SYSTEM)"
	
	// Setting the file path for each language to be used by the module 
	send_command vdvGUILanguageManager, "'LangFilePath-', itoa(1),',', GUI_TEXT_FILE_PATH_LIST[1]"
	send_command vdvGUILanguageManager, "'LangFilePath-', itoa(2),',', GUI_TEXT_FILE_PATH_LIST[2]"
	
	// Setting the touch panel encoding, becuase in this program a G4 touch panel is being used
	// touch panel encoding will be set to UNI
	send_command vdvGUILanguageManager, "'TPEnc-UNI'"

	// Make sure to pass a valid license and activation keys to the module to use it in full version 
	// you can get license and activation keys by visiting www.ultcontrol.com/modules/gui-language-manager/
	send_command vdvGUILanguageManager, "'ACTIVATE-THELICENSEKEY,THEACIVATIONKEY'"

	// Sending the "REINIT" command to the module to re-initialize the module
	send_command vdvGUILanguageManager, "'REINIT'"
    }
    offline:
    {
	send_string 0, "'Module is Offline'"
    }
}


//////////////////////////////////
// Module Channel Events 	// 
//////////////////////////////////

// Language selection events 
channel_event[vdvGUILanguageManager, 101]
channel_event[vdvGUILanguageManager, 102]
channel_event[vdvGUILanguageManager, 103]
channel_event[vdvGUILanguageManager, 104]
channel_event[vdvGUILanguageManager, 105]
{
    ON:
    {
	// Updating the variable tracing the currently selected language 
	currentLanguageIndex = channel.channel - 100
	
	// Updating the selected language feedback on the touch panel
	[dvTP, BUTTON_LANGUAGE_SELECT_LANG1] = (currentLanguageIndex == 1)
	[dvTP, BUTTON_LANGUAGE_SELECT_LANG2] = (currentLanguageIndex == 2)
    }
}

// Module activation event
channel_event[vdvGUILanguageManager, 201]
{
    ON:
    {
	// Updating the module activation feedback on the touch panel 
	[dvTP, BUTTON_MODULE_ACTIVATED] = [vdvGUILanguageManager, 201]
    }
    OFF:
    {
	// Updating the module activation feedback on the touch panel 
	[dvTP, BUTTON_MODULE_ACTIVATED] = [vdvGUILanguageManager, 201]
    }
}

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM


(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)
